#include <windows.h>

#define OHBEXPORT __declspec(dllexport)
#include "ohbbhlp.h"
#include "ohbabel.h"
#include "oheztr.h"
/* add new header here */

typedef struct _OHBTRANSFUNC
{
  int (*pfnOhbInit)(const OHBSETTING *pSetting);
  const OHBTRANS * (*pfnOhbTrans)(LPCWSTR lpStr, const OHBSETTING *pSetting);
  void (*pfnOhbFree)(const OHBTRANS *ohbTrans);
  void (*pfnOhbDestroy)(void);
} OHBTRANSFUNC;

static OHBTRANSFUNC arrOhbTransFuncs[] =
  {
    /* 0 */
    {
      &OhbEZTRJKInit,
      &OhbEZTRJKTrans,
      &OhbEZTRJKFree,
      &OhbEZTRJKDestroy
    },
    /* 1 */
    {
      &OhbEZTRKJInit,
      &OhbEZTRKJTrans,
      &OhbEZTRKJFree,
      &OhbEZTRKJDestroy
    },
    /* 2 */
    {
      &OhbBabelJKInit,
      &OhbBabelJKTrans,
      &OhbBabelJKFree,
      &OhbBabelJKDestroy
    },
    /* 3 */
    {
      &OhbBabelKJInit,
      &OhbBabelKJTrans,
      &OhbBabelKJFree,
      &OhbBabelKJDestroy
    }
    /* add new translator functions here */
  };

static OHBSETTING arrSettings[] =
  {
    /* 0 */
    {
      OHBID_INVALID,
      L"Japanese-Korean (ezTrans XP)",
      NULL,
      ""
    },
    /* 1 */
    {
      OHBID_INVALID,
      L"Korean-Japanese (ezTrans XP)",
      NULL,
      ""
    },
    /* 2 */
    {
      OHBID_INVALID,
      L"Japanese-Korean (Babel TOP 2002)",
      NULL,
      ""
    },
    /* 3 */
    {
      OHBID_INVALID,
      L"Korean-Japanese (Babel TOP 2002)",
      NULL,
      ""
    }
    /* add new translator settings here */
  };

static const int nSettings = sizeof(arrSettings) / sizeof(arrSettings[0]);

OHBEXPORT int OHBCALL OhbInit(OHBTRANSID iTransID)
{
  if (arrOhbTransFuncs[iTransID].pfnOhbInit(&arrSettings[iTransID]) == 0)
  {
    arrSettings[iTransID].iTransID = iTransID;
    return 0;
  }

  return -1;
}

OHBEXPORT void OHBCALL OhbDestroy(OHBTRANSID iTransID)
{
  arrOhbTransFuncs[iTransID].pfnOhbDestroy();
}

OHBEXPORT const OHBSETTING * OHBCALL OhbGetSettings(int *piSettings)
{
  *piSettings = nSettings;

  return arrSettings;
}

OHBEXPORT const OHBTRANS * OHBCALL OhbTrans(LPCWSTR lpStr,
  const OHBSETTING *pSetting)
{
  return arrOhbTransFuncs[pSetting->iTransID].pfnOhbTrans(lpStr, pSetting);
}

OHBEXPORT void OHBCALL OhbFree(const OHBTRANS *ohbTrans)
{
  arrOhbTransFuncs[ohbTrans->pSetting->iTransID].pfnOhbFree(ohbTrans);
}

